@@ -1,13 +1,15 @@
 var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();
 
-import React, { PropTypes } from 'react';
+import React from 'react';
+import PropTypes from 'prop-types';
 import Panel from './panel';
 import IconVisible from 'react-icons/lib/fa/eye';
-import IconHide from 'react-icons/lib/fa/eye-slash';
 import IconAdd from 'react-icons/lib/ti/plus';
 import IconEdit from 'react-icons/lib/fa/pencil';
 import IconTrash from 'react-icons/lib/fa/trash';
 
+import { MODE_IDLE, MODE_2D_ZOOM_IN, MODE_2D_ZOOM_OUT, MODE_2D_PAN, MODE_3D_VIEW, MODE_3D_FIRST_PERSON, MODE_WAITING_DRAWING_LINE, MODE_DRAWING_LINE, MODE_DRAWING_HOLE, MODE_DRAWING_ITEM, MODE_DRAGGING_LINE, MODE_DRAGGING_VERTEX, MODE_DRAGGING_ITEM, MODE_DRAGGING_HOLE, MODE_FITTING_IMAGE, MODE_UPLOADING_IMAGE, MODE_ROTATING_ITEM, MODE_CONFIGURING_LAYER } from '../../constants';
+
 var STYLE_ADD_WRAPPER = {
   color: "#fff",
   textDecoration: "none",
@@ -49,6 +51,8 @@ export default function PanelLayers(_ref, _ref2) {
       translator = _ref2.translator;
 
 
+  if (![MODE_IDLE, MODE_2D_ZOOM_IN, MODE_2D_ZOOM_OUT, MODE_2D_PAN, MODE_3D_VIEW, MODE_3D_FIRST_PERSON, MODE_WAITING_DRAWING_LINE, MODE_DRAWING_LINE, MODE_DRAWING_HOLE, MODE_DRAWING_ITEM, MODE_DRAGGING_LINE, MODE_DRAGGING_VERTEX, MODE_DRAGGING_ITEM, MODE_DRAGGING_HOLE, MODE_ROTATING_ITEM, MODE_UPLOADING_IMAGE, MODE_FITTING_IMAGE, MODE_CONFIGURING_LAYER].includes(mode)) return null;
+
   var addClick = function addClick(event) {
     sceneActions.addLayer();
     event.stopPropagation();
@@ -96,7 +100,8 @@ export default function PanelLayers(_ref, _ref2) {
             return sceneActions.openLayerConfigurator(layer.id);
           };
           var delLayer = function delLayer(e) {
-            e.stopPropagation();sceneActions.removeLayer(layerID);
+            e.stopPropagation();
+            sceneActions.removeLayer(layerID);
           };
 
           var swapVisibility = function swapVisibility(e) {
@@ -123,7 +128,8 @@ export default function PanelLayers(_ref, _ref2) {
             React.createElement(
               'td',
               { style: iconColStyle },
-              !isLastLayer ? React.createElement(IconTrash, { onClick: delLayer, style: STYLE_EDIT_BUTTON, title: translator.t("Delete layer") }) : null
+              !isLastLayer ? React.createElement(IconTrash, { onClick: delLayer, style: STYLE_EDIT_BUTTON,
+                title: translator.t("Delete layer") }) : null
             ),
             React.createElement(
               'td',
