@@ -264,7 +264,8 @@ export default class ElementEditor extends Component {
 
         <AttributesEditor element={this.props.element}
                           onUpdate={this.updateAttribute}
-                          attributeFormData={attributesFormData}/>
+                          attributeFormData={attributesFormData}
+                          state={appState}/>
 
         {propertiesFormData.entrySeq()
           .map(([propertyName, data]) => {
@@ -288,17 +289,17 @@ export default class ElementEditor extends Component {
 
         <table style={tableStyle}>
           <tbody>
-            <tr>
-              <td>
-                <DeleteButton size="small" onClick={e => projectActions.remove()}>{translator.t("Delete")}</DeleteButton>
-              </td>
-              <td>
-                <CancelButton size="small" onClick={e => this.reset()}>{translator.t("Reset")}</CancelButton>
-              </td>
-              <td>
-                <FormSubmitButton size="small">{translator.t("Save")}</FormSubmitButton>
-              </td>
-            </tr>
+          <tr>
+            <td>
+              <DeleteButton size="small" onClick={e => projectActions.remove()}>{translator.t("Delete")}</DeleteButton>
+            </td>
+            <td>
+              <CancelButton size="small" onClick={e => this.reset()}>{translator.t("Reset")}</CancelButton>
+            </td>
+            <td>
+              <FormSubmitButton size="small">{translator.t("Save")}</FormSubmitButton>
+            </td>
+          </tr>
           </tbody>
         </table>
 
